@@ -2,7 +2,7 @@
 ### These are "cheap" to program, but potentially far from efficient;
 ### Methods for specific subclasses will overwrite these:
 
-setAs("ANY",    "denseMatrix", function(from) Matrix(from, sparse=FALSE))
+setAs("ANY", "denseMatrix", function(from) Matrix(from, sparse=FALSE, doDiag=FALSE))
 ## Conceivably, could write
 ## setAs("matrix", "denseMatrix", ....) which was slightly more efficient than
 ##  Matrix(.)  but would have many things in common
@@ -262,3 +262,11 @@ setMethod("is.na", signature(x = "denseMatrix"),
 		      i = integer(0), p = rep.int(0L, d[2]+1L))
 	      }
 	  })
+
+if(.Matrix.avoiding.as.matrix) {
+setMethod("qr", signature(x = "ddenseMatrix"),
+	  function(x, ...) qr.default(ge2mat(..2dge(x)), ...))
+setMethod("qr", signature(x = "denseMatrix"),
+	  function(x, ...) qr(as(x, "ddenseMatrix"), ...))
+}
+
