@@ -12,6 +12,19 @@ extern "C" {
 #include <R.h>  /* includes Rconfig.h */
 #include <Rversion.h>
 #include <Rdefines.h> /* Rinternals.h + GET_SLOT etc */
+#include <R_ext/RS.h> /* for Memzero() */
+
+// must come after <R.h> above, for clang (2015-08-05)
+#ifdef __GNUC__
+# undef alloca
+# define alloca(x) __builtin_alloca((x))
+#elif defined(__sun) || defined(_AIX)
+/* this is necessary (and sufficient) for Solaris 10 and AIX 6: */
+# include <alloca.h>
+#endif
+/* For R >= 3.2.2, the 'elif' above shall be replaced by
+#elif defined(HAVE_ALLOCA_H)
+*/
 
 #ifdef ENABLE_NLS
 #include <libintl.h>
@@ -22,14 +35,6 @@ extern "C" {
 #define dngettext(pkg, String, StringP, N) (N > 1 ? StringP : String)
 #endif
 
-#ifdef __GNUC__
-# undef alloca
-# define alloca(x) __builtin_alloca((x))
-#elif defined(__sun) || defined(_AIX)
-/* this is necessary (and sufficient) for Solaris 10 and AIX 6: */
-# include <alloca.h>
-#endif
-
 #ifndef LONG_VECTOR_SUPPORT
 // notably for  R <= 2.15.x :
 # define XLENGTH(x) LENGTH(x)
@@ -40,9 +45,23 @@ extern "C" {
 
 #define Alloca(n, t)   (t *) alloca( (size_t) ( (n) * sizeof(t) ) )
 
+#define SMALL_4_Alloca 10000
+//			==== R uses the same cutoff in several places
+
+#define C_or_Alloca_TO(_VAR_, _N_, _TYPE_)			\
+	if(_N_ < SMALL_4_Alloca) {				\
+	    _VAR_ = Alloca(_N_, _TYPE_);  R_CheckStack();	\
+	} else {						\
+	    _VAR_ = Calloc(_N_, _TYPE_);			\
+	}
+// and user needs to   if(_N_ >= SMALL_4_Alloca)  Free(_VAR_);
+
 SEXP triangularMatrix_validate(SEXP obj);
 SEXP symmetricMatrix_validate(SEXP obj);
 SEXP dense_nonpacked_validate(SEXP obj);
+SEXP dim_validate(SEXP Dim, const char* name);
+SEXP Dim_validate(SEXP obj, SEXP name);
+SEXP dimNames_validate(SEXP obj);
 
 // La_norm_type() & La_rcond_type()  have been in R_ext/Lapack.h
 //  but have still not been available to package writers ...
@@ -120,8 +139,6 @@ extern	 /* stored pointers to symbols initialized in R_init_Matrix */
 
 /* zero an array */
 #define AZERO(x, n) {int _I_, _SZ_ = (n); for(_I_ = 0; _I_ < _SZ_; _I_++) (x)[_I_] = 0;}
-// R's  RS.h :
-#define Memzero(p,n)  memset(p, 0, (size_t)(n) * sizeof(*p))
 
 /* number of elements in one triangle of a square matrix of order n */
 #define PACKED_LENGTH(n)   ((n) * ((n) + 1))/2
@@ -358,10 +375,15 @@ mMatrix_as_geMatrix(SEXP A)
 		    "nsyMatrix",		\
 		    "ntpMatrix", "nspMatrix"
 
+#define MATRIX_VALID_dCsparse			\
+ "dgCMatrix", "dsCMatrix", "dtCMatrix"
+#define MATRIX_VALID_nCsparse			\
+ "ngCMatrix", "nsCMatrix", "ntCMatrix"
+
 #define MATRIX_VALID_Csparse			\
- "dgCMatrix", "dsCMatrix", "dtCMatrix",		\
+    MATRIX_VALID_dCsparse,			\
  "lgCMatrix", "lsCMatrix", "ltCMatrix",		\
- "ngCMatrix", "nsCMatrix", "ntCMatrix",		\
+    MATRIX_VALID_nCsparse,			\
  "zgCMatrix", "zsCMatrix", "ztCMatrix"
 
 #define MATRIX_VALID_Tsparse			\
@@ -398,6 +420,7 @@ mMatrix_as_geMatrix(SEXP A)
 /**
  * Return the 0-based index of a string match in a vector of strings
  * terminated by an empty string.  Returns -1 for no match.
+ * Is  __cheap__ :  __not__ looking at superclasses --> better use  R_check_class_etc(obj, *)
  *
  * @param class string to match
  * @param valid vector of possible matches terminated by an empty string
@@ -417,9 +440,20 @@ Matrix_check_class(char *class, const char **valid)
 /**
  * These are the ones "everyone" should use -- is() versions, also looking
  * at super classes:
+
+ * They now use R(semi_API) from  Rinternals.h :
+ * int R_check_class_and_super(SEXP x, const char **valid, SEXP rho);
+ * int R_check_class_etc      (SEXP x, const char **valid);
+
+ * R_check_class_etc      (x, v)      basically does  rho <- .classEnv(x)  and then calls
+ * R_check_class_and_super(x, v, rho)
  */
+// No longer:
+#ifdef DEPRECATED_Matrix_check_class_
 # define Matrix_check_class_etc R_check_class_etc
 # define Matrix_check_class_and_super R_check_class_and_super
+#endif
+
 
 /** Accessing  *sparseVectors :  fast (and recycling)  v[i] for v = ?sparseVector:
  * -> ./sparseVector.c  -> ./t_sparseVector.c :
