@@ -24,9 +24,9 @@ SEXP Tsparse_validate(SEXP x)
 
     for (j = 0; j < nnz; j++) {
 	if (xi[j] < 0 || xi[j] >= nrow)
-	    return mkString(_("all row indices must be between 0 and nrow-1"));
+	    return mkString(_("all row indices (slot 'i') must be between 0 and nrow-1 in a TsparseMatrix"));
 	if (xj[j] < 0 || xj[j] >= ncol)
-	    return mkString(_("all column indices must be between 0 and ncol-1"));
+	    return mkString(_("all column indices (slot 'j') must be between 0 and ncol-1 in a TsparseMatrix"));
     }
     return ScalarLogical(1);
 }
@@ -70,7 +70,7 @@ SEXP Tsparse_diagU2N(SEXP x)
 	""};
 /* #define xSXP(iTyp) ((iTyp == 0) ? REALSXP : ((iTyp == 1) ? LGLSXP : /\* else *\/ CPLXSXP)); */
 /* #define xTYPE(iTyp) ((iTyp == 0) ? double : ((iTyp == 1) ? int : /\* else *\/ Rcomplex)); */
-    int ctype = Matrix_check_class_etc(x, valid);
+    int ctype = R_check_class_etc(x, valid);
 
     if (ctype < 0 || *diag_P(x) != 'U') {
 	/* "trivially fast" when not triangular (<==> no 'diag' slot),
