@@ -42,13 +42,13 @@ static R_CallMethodDef CallEntries[] = {
     CALLDEF(CHMfactor_updown,3),
     CALLDEF(destructive_CHM_update, 3),
     CALLDEF(Cholesky_validate, 1),
-    CALLDEF(Csparse_Csparse_prod, 2),
-    CALLDEF(Csparse_Csparse_crossprod, 3),
+    CALLDEF(Csparse_Csparse_prod, 3),
+    CALLDEF(Csparse_Csparse_crossprod, 4),
     CALLDEF(Csparse_MatrixMarket, 2),
     CALLDEF(Csparse_band, 3),
-    CALLDEF(Csparse_crossprod, 3),
-    CALLDEF(Csparse_dense_crossprod, 2),
-    CALLDEF(Csparse_dense_prod, 2),
+    CALLDEF(Csparse_crossprod, 4),
+    CALLDEF(Csparse_dense_crossprod, 3),
+    CALLDEF(Csparse_dense_prod, 3),
     CALLDEF(Csparse_diagN2U, 1),
     CALLDEF(Csparse_diagU2N, 1),
     CALLDEF(Csparse_drop, 2),
@@ -57,9 +57,9 @@ static R_CallMethodDef CallEntries[] = {
     CALLDEF(Csparse_to_Tsparse, 2),
     CALLDEF(Csparse_to_tCsparse, 3),
     CALLDEF(Csparse_to_tTsparse, 3),
-    CALLDEF(Csparse_to_dense, 1),
+    CALLDEF(Csparse_to_dense, 2),
     CALLDEF(Csparse_to_nz_pattern, 2),
-    CALLDEF(Csparse_to_matrix, 2),
+    CALLDEF(Csparse_to_matrix, 3),
     CALLDEF(Csparse_to_vector, 1),
     CALLDEF(Csparse_submatrix, 3),
     CALLDEF(dCsparse_subassign, 4),
@@ -67,7 +67,7 @@ static R_CallMethodDef CallEntries[] = {
     CALLDEF(iCsparse_subassign, 4),
     CALLDEF(nCsparse_subassign, 4),
     CALLDEF(zCsparse_subassign, 4),
-    CALLDEF(Csparse_general_to_symmetric, 2),
+    CALLDEF(Csparse_general_to_symmetric, 3),
     CALLDEF(Csparse_symmetric_to_general, 1),
     CALLDEF(Csparse_transpose, 2),
     CALLDEF(Csparse_validate, 1),
@@ -76,16 +76,17 @@ static R_CallMethodDef CallEntries[] = {
     CALLDEF(pCholesky_validate, 1),
     CALLDEF(Rsparse_validate, 1),
     CALLDEF(diag_tC, 2),
-#ifdef _valid_only_for_old_graph_package
-    CALLDEF(graphNEL_as_dgTMatrix, 2),
-#endif
     CALLDEF(LU_expand, 1),
     CALLDEF(LU_validate, 1),
+    CALLDEF(MatrixFactorization_validate, 1),
     CALLDEF(Matrix_expand_pointers, 1),
+    CALLDEF(R_rbind2_vector, 2),
     CALLDEF(R_all0, 1),
     CALLDEF(R_any0, 1),
     CALLDEF(R_to_CMatrix, 1),
+#ifdef _Matrix_has_SVD_
     CALLDEF(SVD_validate, 1),
+#endif
     CALLDEF(Tsparse_validate, 1),
     CALLDEF(Tsparse_diagU2N, 1),
     CALLDEF(Tsparse_to_Csparse, 2),
@@ -99,10 +100,12 @@ static R_CallMethodDef CallEntries[] = {
     CALLDEF(dense_to_symmetric, 3),
     CALLDEF(ddense_symmpart, 1),
     CALLDEF(ddense_skewpart, 1),
+    CALLDEF(dimNames_validate, 1),
+    CALLDEF(Dim_validate, 2),
     CALLDEF(dMatrix_validate, 1),
 
-    CALLDEF(dgCMatrix_LU, 4),
-    CALLDEF(dgCMatrix_QR, 2),
+    CALLDEF(dgCMatrix_LU, 5),
+    CALLDEF(dgCMatrix_QR, 3),
 #ifdef Matrix_with_SPQR
     CALLDEF(dgCMatrix_SPQR, 4),
 #endif
@@ -122,9 +125,12 @@ static R_CallMethodDef CallEntries[] = {
     CALLDEF(dgeMatrix_Schur, 3),
     CALLDEF(dgeMatrix_colsums, 4),
     CALLDEF(dgeMatrix_crossprod, 2),
+    CALLDEF (geMatrix_crossprod, 2),
     CALLDEF(dgeMatrix_determinant, 2),
     CALLDEF(dgeMatrix_dgeMatrix_crossprod, 3),
+    CALLDEF (geMatrix_geMatrix_crossprod, 3),
     CALLDEF(dgeMatrix_matrix_mm, 3),
+    CALLDEF (geMatrix_matrix_mm, 3),
     CALLDEF(dgeMatrix_matrix_solve, 2),
     CALLDEF(dgeMatrix_dtpMatrix_mm, 2),
     CALLDEF(dgeMatrix_exp, 1),
@@ -134,6 +140,7 @@ static R_CallMethodDef CallEntries[] = {
     CALLDEF(dgeMatrix_setDiag, 2),
     CALLDEF(lgeMatrix_setDiag, 2),
     CALLDEF(dgeMatrix_matrix_crossprod, 3),
+    CALLDEF (geMatrix_matrix_crossprod, 3),
     CALLDEF(dgeMatrix_norm, 2),
     CALLDEF(dgeMatrix_rcond, 2),
     CALLDEF(dgeMatrix_solve, 1),
@@ -241,11 +248,12 @@ static R_CallMethodDef CallEntries[] = {
     CALLDEF(lsq_dense_Chol, 2),
     CALLDEF(lsq_dense_QR, 2),
     CALLDEF(sparseQR_validate, 1),
-    CALLDEF(sparseQR_qty, 3),
+    CALLDEF(sparseQR_qty, 4),
     CALLDEF(sparseQR_coef, 2),
     CALLDEF(sparseQR_resid_fitted, 3),
     CALLDEF(triangularMatrix_validate, 1),
     CALLDEF(symmetricMatrix_validate, 1),
+    CALLDEF(R_symmetric_Dimnames, 1),
 
 /* still simple placeholders, but already used in ../R/AllClass.R : */
     CALLDEF(CHMfactor_validate, 1),
@@ -289,6 +297,7 @@ R_init_Matrix(DllInfo *dll)
 
     RREGDEF(as_cholmod_dense);
     RREGDEF(as_cholmod_factor);
+    RREGDEF(as_cholmod_factor3);
     RREGDEF(as_cholmod_sparse);
     RREGDEF(as_cholmod_triplet);
     RREGDEF(chm_factor_to_SEXP);
@@ -323,6 +332,7 @@ R_init_Matrix(DllInfo *dll)
     RREGDEF(cholmod_scale);
     RREGDEF(cholmod_sdmult);
     RREGDEF(cholmod_solve);
+    RREGDEF(cholmod_solve2);
     RREGDEF(cholmod_sort);
     RREGDEF(cholmod_sparse_to_dense);
     RREGDEF(cholmod_sparse_to_triplet);
@@ -340,8 +350,9 @@ R_init_Matrix(DllInfo *dll)
     RREGDEF(numeric_as_chm_dense);
 
     R_cholmod_start(&c);
-//    R_cholmod_l_start(&cl);
+//    R_cholmod_start(&cl); << TODO; needs more work in ./chm_common.c etc
 
+    Matrix_betaSym = install("beta");
     Matrix_DimNamesSym = install("Dimnames");
     Matrix_DimSym = install("Dim");
     Matrix_diagSym = install("diag");
@@ -353,6 +364,7 @@ R_init_Matrix(DllInfo *dll)
     Matrix_permSym = install("perm");
     Matrix_uploSym = install("uplo");
     Matrix_xSym = install("x");
+    Matrix_VSym = install("V");
 
     Matrix_NS = R_FindNamespace(mkString("Matrix"));
     if(Matrix_NS == R_UnboundValue)
