@@ -18,7 +18,7 @@ stopifnot(all.equal(mmT, mmT.))
 ## Should be the same but not quite: even length( * @ x ) differs!
 ##str(mmT, max=2)# much larger than mTm (i.e less sparse)
 ##str(mmT., max=2)# x slot is currently slightly larger --> improve tcrossprod()?
-##system.time(ae <- all.equal(as(mmT.,"matrix"), as(mmT,"matrix"), tol = 1e-14))
+##system.time(ae <- all.equal(as(mmT.,"matrix"), as(mmT,"matrix"), tolerance = 1e-14))
 ## 4-5 seconds on a 850 MHz, P III
 ##stopifnot(ae)
 
@@ -36,8 +36,8 @@ for(i in 1:10) {
     A    <- as(Am, "dgeMatrix")
     b <- matrix(rnorm(400), nrow = 4, ncol = 100)
     B <- as(b, "dgeMatrix")
-    assert.EQ.mat(A %*% B, Am %*%  b, tol=0)
-    assert.EQ.mat(B %*% A,  b %*% Am, tol=0)
+    assert.EQ.mat(A %*% B, Am %*%  b)
+    assert.EQ.mat(B %*% A,  b %*% Am)
     stopifnot(identical(A, as(Acsc, "dgeMatrix")),
               identical(Acsc, as(A, "dgCMatrix")),
               is.all.equal4(A %*% B, Acsc %*% B,
@@ -62,8 +62,8 @@ mc <- as(m1, "dgCMatrix")
 m2 <- as(mc, "dgTMatrix")## the same as 'm1' but without duplicates
 
 stopifnot(!isTRUE(all.equal.default(m1, m2)),
-          all.equal(as(m1,"matrix"), as(m2,"matrix"), tol=1e-15),
-          all.equal(crossprod(m1), crossprod(m2), tol=1e-15),
+          all.equal(as(m1,"matrix"), as(m2,"matrix"), tolerance =1e-15),
+          all.equal(crossprod(m1), crossprod(m2), tolerance =1e-15),
           identical(mc, as(m2, "dgCMatrix")))
 
 ### -> uniq* functions now in ../R/Auxiliaries.R
@@ -72,7 +72,7 @@ stopifnot(identical(m2,um2))
 
 ### -> error/warning condition for solve() of a singular matrix (Barry Rowlingson)
 (M <- Matrix(0+ 1:16, nc = 4))
-assertError(solve(M))## -> an error + a warning about singularity -- and caches the LU decomp
+assertError(solve(M), verbose=TRUE)## ".. computationally singular" + warning + caches LU
 assertError(solve(t(M)))
 options(warn=2) # no more warnings allowed from here
 lum <- lu(M, warnSing=FALSE)
